searchNodes=[{"ref":"Wild.html","title":"Wild","type":"module","doc":"A wildcard matching library that implements unix-style blob pattern matching functionality for Elixir binaries. It works on all binary input and defaults to working with codepoint representations of binaries. The match?/3 and valid_pattern?/1 functions support all of the usual wildcard pattern mechanisms: * matches none or many tokens ? matches exactly one token [abc] matches a set of tokens [a-z] matches a range of tokens [!...] matches anything but a set of tokens"},{"ref":"Wild.html#match?/3","title":"Wild.match?/3","type":"function","doc":"Executes a unix-style wildcard blob pattern match on a binary with a given pattern. By default it tokenizes and runs on codepoints but can also be set to byte mode. Examples iex&gt; Wild.match?(&quot;foobar&quot;, &quot;foo*&quot;) true iex&gt; Wild.match?(&quot;foobar&quot;, &quot;fo[a-z]bar&quot;) true iex&gt; Wild.match?(&lt;&lt;9, 97, 98&gt;&gt;, &quot;?ab&quot;) true iex&gt; Wild.match?(&quot;foobar&quot;, &quot;bar*&quot;) false iex&gt; Wild.match?(&lt;&lt;16, 196, 130, 4&gt;&gt;, &quot;????&quot;, mode: :byte) true The options are: :mode - The matching mode. This primarily affects tokenization and what is considered a single match for the ? wildcard. Options are: :codepoint (default) - Tokenize on printable String characters :byte - Tokenize on each byte :bash - Using an underlying bash script. Only for debugging The distinction is important for subject and patterns like the following, where the binary is represented by two bytes but only one codepoint: iex&gt; Wild.match?(&quot;ā&quot;, &quot;?&quot;, mode: :codepoint) true iex&gt; Wild.match?(&quot;ā&quot;, &quot;?&quot;, mode: :byte) false If we do an example tokenization of our &quot;ā&quot; subject we can see that depending on how you treat the binary you can produce different amounts tokens: iex&gt; String.codepoints(&quot;ā&quot;) [&quot;ā&quot;] iex&gt; :binary.bin_to_list(&quot;ā&quot;) [196, 129] If you are dealing with user input from forms this is likely not something you will encounter and can keep the default value of :codepoint. :on_pattern_error - What to do when the pattern is invalid. The options are: :fail (default) - Simliar to case statements in Bash where an invalid pattern won&#39;t match the subject, simply fail the match and return false :return - Returns an {:error, error} tuple :raise - Raise an error"},{"ref":"Wild.html#valid_pattern?/2","title":"Wild.valid_pattern?/2","type":"function","doc":"Checks if the given pattern is a valid unix-style wildcard pattern. The most common invalid patterns arise because of invalid escape sequences. Mode can be either :byte or :codepoint (default). Examples iex&gt; Wild.valid_pattern?(&quot;fo[a-z]b?r&quot;) true iex&gt; Wild.valid_pattern?(&lt;&lt;?\\\\, ?a&gt;&gt;) false iex&gt; Wild.valid_pattern?(&quot;hello&quot;, :codepoint) true iex&gt; Wild.valid_pattern?(123) false"},{"ref":"readme.html","title":"Wild","type":"extras","doc":"Wild Wild is a wildcard matching library that implements unix-style blob pattern matching functionality for Elixir binaries (without actually interacting with the filesystem itself). It works on all binary input and defaults to working with codepoint representations of binaries, but other modes are also available."},{"ref":"readme.html#installation","title":"Wild - Installation","type":"extras","doc":"Add the :wild dependency to your mix.exs file: def deps do [ {:wild, &quot;~&gt; 1.0.0&quot;} ] end"},{"ref":"readme.html#example-usage","title":"Wild - Example Usage","type":"extras","doc":"# Simple match iex&gt; Wild.match?(&quot;foobar&quot;, &quot;foo*&quot;) true # Simple non-match iex&gt; Wild.match?(&quot;foobar&quot;, &quot;bar*&quot;) false # Classes are supported iex&gt; Wild.match?(&quot;foobar&quot;, &quot;fo[a-z]bar&quot;) true # Non-printable binaries can be matched in byte mode iex&gt; Wild.match?(&lt;&lt;16, 196, 130, 4&gt;&gt;, &quot;????&quot;, mode: :byte) true # Check validity of pattern iex&gt; Wild.valid_pattern?(&quot;fo[a-z]b?r&quot;) true"}]